import { Reducer, AnyAction } from "redux";
import { ActionReducerMap, ActionCreator, ActionReducer, ActionFolder, PartialActionReducer, PartialActionFolder } from "./core";
/**
 * Creates a redux standard reducer for a state `TState` from an `ActionHandlerMap<State>`
 *
 * @param handlers
 * @param initialState
 */
export declare function createReducer<TState>(handlers: ActionReducerMap<TState> | ActionReducerMap<TState>[], initialState: TState): Reducer<TState>;
/**
 * Composes any number of reducers of a state type TState into a single reducer of that state type
 *
 * @param reducers
 */
export declare function composeReducers<TState>(...reducers: Reducer<TState>[]): Reducer<TState, AnyAction>;
/**
 *  @deprecated temporary alias for createReducer
 * this alias will be removed in v3.x
 */
export declare const handleActions: typeof createReducer;
export declare type InferPayload<T> = T extends ActionCreator<infer U>[] ? U : T extends ActionCreator<infer P> ? P : never;
/**
 * Registers a reducer handler for one or many actions
 *
 * @param action
 * @param reducer
 */
export declare function reduce<TState, TActions extends ActionCreator<any> | ActionCreator<any>[]>(actions: TActions, reducer: ActionReducer<TState, InferPayload<TActions>>): ActionReducerMap<TState>;
/**
 * Registers a reducer handler for one or many actions
 *
 * @param action
 * @param reducer
 */
export declare function reduceP<TState, TActions extends ActionCreator<any> | ActionCreator<any>[]>(actions: TActions, reducer: PartialActionReducer<TState, InferPayload<TActions>>): ActionReducerMap<TState>;
/**
 * Registers a reducer handler for one or many actions
 *
 * @param action
 * @param reducer
 */
export declare function fold<TState, TActions extends ActionCreator<any> | ActionCreator<any>[]>(actions: TActions, reducer: ActionFolder<TState, InferPayload<TActions>>): ActionReducerMap<TState>;
/**
 * Registers a reducer handler for one or multiple actions
 *
 * @template TState - the reducer state
 * @template TActions
 *
 * @param actions - a single action creator or multiple action creators
 * @param reducer - a `PartialActionFolder`: TPayload -> TState -> TState
 */
export declare function foldP<TState, TActions extends ActionCreator<any> | ActionCreator<any>[]>(actions: TActions, reducer: PartialActionFolder<TState, InferPayload<TActions>>): ActionReducerMap<TState>;
/**
 *  @deprecated temporary alias for `reduce`
 * this alias will be removed in v3.x
 */
export declare const match: typeof reduce;
/**
 *  @deprecated temporary alias for `foldP`
 * this alias will be removed in v3.x
 */
export declare const matchF: typeof foldP;
