import { Dispatch } from "redux";
import { InferableComponentEnhancerWithProps, MapStateToProps } from "react-redux";
import { ActionCreator } from "./core";
import { Tree } from "./helpers/objects";
export { connect, connectAdvanced } from "react-redux";
export declare type Dispatcher<T = any> = (payload: T) => void;
export declare type SelectorSpec<TProps, TState, TOwnProps extends Record<string, any> = any> = {
    [P in keyof TProps]: (state: TState, ownProps?: TOwnProps) => TProps[P];
};
export interface ConnectWithActions {
    <TProps extends {
        actions: TActions;
    }, TOwnProps extends Record<string, any> = any, TActions extends Tree<ActionCreator<any>> = Record<string, any>>(actions: TActions): InferableComponentEnhancerWithProps<TProps, TOwnProps>;
    <TProps extends {
        actions: TActions;
    }, TOwnProps extends Record<string, any> = any, TState extends Record<string, any> = any, TActions extends Tree<ActionCreator<any>> = Record<string, any>>(actions: TActions, mapStateToProps: MapStateToProps<Partial<TProps>, TOwnProps, TState> | SelectorSpec<Partial<TProps>, TState, TOwnProps>): InferableComponentEnhancerWithProps<TProps, TOwnProps>;
}
/**
 * bindActionCreators
 *
 * Monkeypatches dispatch to the actions making them self-dispachable
 *
 * @param actions
 */
export declare const bindActionCreators: <TActions extends Tree<ActionCreator<any, any>>>(actions: TActions) => (dispatch: Dispatch) => {
    actions: TActions;
};
export declare const applySelectors: <TProps = Record<string, any>, TState = Record<string, any>, TOwnProps = Record<string, any>>(spec: SelectorSpec<TProps, TState, TOwnProps>) => MapStateToProps<Partial<TProps>, TOwnProps, TState>;
/**
 * connectWithActions
 *
 * Wraps react-redux's "connect" helper, binding dispatch to the action-creators
 *
 * @param actions - object of action-creators
 * @param mapStateToProps -
 * It can either be a function that directly maps the app's State to a component's Props
 * or an object whose keys represent properties in the target component and values are functions
 * that take the application's State and optionally, the connected component's own Props.
 * Those functions then return a derived value that matches the component's contract.
 * Ideally should be used with redux selectors.
 *
 */
export declare const connectWithActions: ConnectWithActions;
