import { SagaIterator } from "redux-saga";
import { AllEffect, ForkEffect, PutEffect, CallEffect, SelectEffect } from "redux-saga/effects";
import { Action, AsyncActionCreator } from "./core";
export declare type APIWorkerHookEffect<TPayload, TCombiner = any> = PutEffect<Action<TPayload>> | AllEffect<TCombiner> | ForkEffect | CallEffect | SelectEffect;
export interface APIWorkerHooks<TResult, TFailure, TAction> {
    onSuccess(result: TResult, action: TAction): IterableIterator<APIWorkerHookEffect<TResult>>;
    onFailure(error: TFailure, action: TAction): IterableIterator<APIWorkerHookEffect<TFailure>>;
}
/**
 * Higher order saga for handling common remote resource fetching and error handling routines
 *
 * @param asyncAction
 * @param asyncHandler
 * @param hooks
 */
export declare function apiWorkerFactory<TResult, TPayload = void, TFailure extends Error = Error>(asyncAction: AsyncActionCreator<TResult, TPayload>, asyncHandler: TPayload extends void | undefined ? () => Promise<TResult> : (payload: TPayload) => Promise<TResult>, hooks?: Partial<APIWorkerHooks<TResult, TFailure, Action<TPayload>>>): (action: Action<TPayload>) => SagaIterator<any>;
