import { ActionCreator, AsyncActionCreator } from "./core";
/**
 * returns an action-creator function
 *
 * @param type - the action identifier, must be unique
 * @param namespace - optional namespace string to be prepended to the type
 */
export declare function createAction<TPayload = void, TMeta = any>(type: string, namespace?: string): ActionCreator<TPayload, TMeta>;
/**
 * returns a composite action-creator with nested action-creators for request, success and failure
 *
 * @param type - the action identifier, must be unique
 * @param namespace - optional namespace string to be prepended to the type
 */
export declare function createAsyncAction<TResult, TPayload = void, TFailure = Error>(type: string, namespace?: string): AsyncActionCreator<TResult, TPayload, TFailure>;
export declare type ActionCreatorFactory = (type: string, namespace?: string) => any;
export declare type BaseActionCreatorMap = Record<string, ActionCreatorFactory>;
export declare type ActionCreatorMap<T extends BaseActionCreatorMap> = {
    [P in keyof T]: ReturnType<T[P]>;
};
export declare class CreateActionsAPI {
    static action: <TPayload = void, TMeta = any>() => (type: string, namespace?: string | undefined) => ActionCreator<TPayload, TMeta>;
    static asyncAction: <TResult, TPayload = void, TError = Error>() => (type: string, namespace?: string | undefined) => AsyncActionCreator<TResult, TPayload, TError>;
}
export declare type ActionsConstructor<T> = (api: typeof CreateActionsAPI) => T;
/**
 * Creates an object with namespaced action-creators
 *
 * @param namespace - string - a namespace to be prepended to the generated action types
 * @param actionsContructor
 */
export declare function createActions<T extends BaseActionCreatorMap>(actionsContructor: ActionsConstructor<T>): ActionCreatorMap<T>;
export declare function createActions<T extends BaseActionCreatorMap>(namespace: string, actionsContructor: ActionsConstructor<T>): ActionCreatorMap<T>;
