import { __assign, __read } from "tslib";
import uncurryN from "ramda/src/uncurryN";
import flip from "ramda/src/flip";
import { toUpperSnakeCase } from "./helpers/strings";
/**
 * returns an action-creator function
 *
 * @param type - the action identifier, must be unique
 * @param namespace - optional namespace string to be prepended to the type
 */
export function createAction(type, namespace) {
    var $type = toUpperSnakeCase(namespace ? namespace + "/" + type : type);
    var baseActionCreator = function (payload, options) { return ({
        error: options ? options.error : undefined,
        meta: options ? options.meta : undefined,
        payload: payload,
        type: $type,
    }); };
    var extensions = {
        type: $type,
        reduce: function (handler) {
            var _a;
            return (_a = {},
                _a[$type] = handler,
                _a);
        },
        reduceP: function (handler) {
            var _a;
            return (_a = {},
                _a[$type] = uncurryN(2, handler),
                _a);
        },
        fold: function (handler) {
            var _a;
            return (_a = {},
                _a[$type] = flip(handler),
                _a);
        },
        foldP: function (handler) {
            var _a;
            return (_a = {},
                _a[$type] = flip(uncurryN(2, handler)),
                _a);
        },
    };
    return Object.assign(baseActionCreator, extensions);
}
/**
 * returns a composite action-creator with nested action-creators for request, success and failure
 *
 * @param type - the action identifier, must be unique
 * @param namespace - optional namespace string to be prepended to the type
 */
export function createAsyncAction(type, namespace) {
    var baseAction = createAction(type, namespace);
    var extensions = {
        request: createAction(type + "_REQUEST", namespace),
        success: createAction(type + "_SUCCESS", namespace),
        failure: createAction(type + "_FAILURE", namespace),
        cancel: createAction(type + "_CANCEL", namespace),
    };
    return Object.assign(baseAction, extensions);
}
var CreateActionsAPI = /** @class */ (function () {
    function CreateActionsAPI() {
    }
    CreateActionsAPI.action = function () { return function (type, namespace) {
        return createAction(type, namespace);
    }; };
    CreateActionsAPI.asyncAction = function () { return function (type, namespace) {
        return createAsyncAction(type, namespace);
    }; };
    return CreateActionsAPI;
}());
export { CreateActionsAPI };
export function createActions() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    var namespace = args.length === 1 ? undefined : args[0];
    var actionsContructor = args.length === 1 ? args[0] : args[1];
    var defs = actionsContructor(CreateActionsAPI);
    return Object.entries(defs).reduce(function (actionCreatorMap, _a) {
        var _b;
        var _c = __read(_a, 2), key = _c[0], factory = _c[1];
        return (__assign(__assign({}, actionCreatorMap), (_b = {}, _b[key] = factory(key, namespace), _b)));
    }, {});
}
//# sourceMappingURL=actions.js.map