import mapObjIndexed from "ramda/src/mapObjIndexed";
/**
 * Applies a transform function recursively to each leaf in a tree
 *
 * @param transform - a function to be applied to each leaf
 * @param tree - a tree-like object with deeply nested props
 */
export function transformTree(transform, tree) {
    return mapObjIndexed(function (value, key) {
        return typeof value === "object"
            ? transformTree(transform, value)
            : transform(value, key);
    }, tree);
}
/**
 * Verifies whether the `target` has all the properties in `props`
 *
 * @param props
 * @param target
 */
export function hasOwnProps(props, target) {
    var hasOwnProp = function (prop) {
        return Object.prototype.hasOwnProperty.call(target, prop);
    };
    return props.every(hasOwnProp);
}
//# sourceMappingURL=objects.js.map