import { useMemo } from "react";
import applySpec from "ramda/src/applySpec";
import { useDispatch, useSelector } from "react-redux";
import { bindActionCreators } from "./redux";
/**
 * Return store-bound action-creators.
 *
 * @param unboundActions action-creators generated by "re-reduced/createActions"
 */
export function useActions(unboundActions) {
    var dispatch = useDispatch();
    var boundActions = useMemo(function () {
        var actions = bindActionCreators(unboundActions)(dispatch).actions;
        return actions;
    }, [dispatch, unboundActions]);
    return boundActions;
}
/**
 * Returns the deriver redux state based on a map of state seelctors
 *
 * @param stateMapper either normal mapStateToProps (without ownProps as 2nd parameter) or selectorSpecs
 */
export function useReduxState(stateMapper) {
    var stateToProps = useMemo(function () {
        return typeof stateMapper === "object"
            ? // selector
                applySpec(stateMapper)
            : // mapStateFn
                stateMapper;
    }, [stateMapper]);
    var state = useSelector(stateToProps);
    return state;
}
//# sourceMappingURL=hooks.js.map