export declare type Nullable<T> = T | null;
export declare type Optional<T> = Nullable<void | undefined | T>;
export declare const REQUEST_STATUS: {
    readonly Idle: "Idle";
    readonly Pending: "Pending";
    readonly Failed: "Failed";
    readonly Fulfilled: "Fulfilled";
    readonly Cancelled: "Cancelled";
};
export declare const INITIAL_REQUEST_STATE: RequestState;
export declare type RequestStatus = keyof typeof REQUEST_STATUS;
export interface RequestState<TError = Error> {
    status: RequestStatus;
    error?: TError;
    lastExecuted?: number;
    lastRequested?: number;
}
export interface AsyncCollection<TResult, TError = Error> {
    byId: Record<string, TResult>;
    idList: string[];
    request: RequestState<TError>;
}
export interface Result<T> {
    items: T;
}
export declare type PaginationQuery = Optional<{
    pageIndex: number;
    pageSize: number;
}>;
export declare type PaginationState = null | (PaginationQuery & {
    total: number;
});
export interface PaginatedResult<T> extends Result<T> {
    pagination: PaginationState;
}
export declare type CacheControl = void | {
    /**
     * Whether the saga should ignore cache validation for this action
     */
    ignoreCache?: boolean;
};
