import mergeAll from "ramda/src/mergeAll";
import merge from "ramda/src/merge";
/**
 * Creates a redux standard reducer for a state `TState` from an `ActionHandlerMap<State>`
 *
 * @param handlers
 * @param initialState
 */
export function createReducer(handlers, initialState) {
    var $handlers = Array.isArray(handlers)
        ? mergeAll(handlers)
        : handlers;
    return function (state, action) {
        if (state === void 0) { state = initialState; }
        var actionReducer = $handlers[action.type];
        if (typeof actionReducer === "function") {
            return actionReducer(state, action.payload);
        }
        return state;
    };
}
/**
 * Composes any number of reducers of a state type TState into a single reducer of that state type
 *
 * @param reducers
 */
export function composeReducers() {
    var reducers = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        reducers[_i] = arguments[_i];
    }
    return (function (state, action) {
        return reducers.reduce(function (nextState, reducer) { return reducer(nextState, action); }, state);
    });
}
/**
 *  @deprecated temporary alias for createReducer
 * this alias will be removed in v3.x
 */
export var handleActions = createReducer;
/**
 * Registers a reducer handler for one or many actions
 *
 * @param action
 * @param reducer
 */
export function reduce(actions, reducer) {
    return Array.isArray(actions)
        ? actions.reduce(function (acc, action) {
            return merge(acc, action.reduce(reducer));
        }, {})
        : actions.reduce(reducer);
}
/**
 * Registers a reducer handler for one or many actions
 *
 * @param action
 * @param reducer
 */
export function reduceP(actions, reducer) {
    return Array.isArray(actions)
        ? actions.reduce(function (acc, action) {
            return merge(acc, action.reduceP(reducer));
        }, {})
        : actions.reduceP(reducer);
}
/**
 * Registers a reducer handler for one or many actions
 *
 * @param action
 * @param reducer
 */
export function fold(actions, reducer) {
    return Array.isArray(actions)
        ? actions.reduce(function (acc, action) { return merge(acc, action.fold(reducer)); }, {})
        : actions.fold(reducer);
}
/**
 * Registers a reducer handler for one or multiple actions
 *
 * @template TState - the reducer state
 * @template TActions
 *
 * @param actions - a single action creator or multiple action creators
 * @param reducer - a `PartialActionFolder`: TPayload -> TState -> TState
 */
export function foldP(actions, reducer) {
    return Array.isArray(actions)
        ? actions.reduce(function (acc, action) { return merge(acc, action.foldP(reducer)); }, {})
        : actions.foldP(reducer);
}
/**
 *  @deprecated temporary alias for `reduce`
 * this alias will be removed in v3.x
 */
export var match = reduce;
/**
 *  @deprecated temporary alias for `foldP`
 * this alias will be removed in v3.x
 */
export var matchF = foldP;
//# sourceMappingURL=reducers.js.map