import { compose } from "redux";
import { connect, } from "react-redux";
import applySpec from "ramda/src/applySpec";
import { transformTree, hasOwnProps } from "./helpers/objects";
export { connect, connectAdvanced } from "react-redux";
function isAsyncActionCreator(action) {
    return hasOwnProps(["request", "success", "failure", "cancel"], action);
}
var toDispatcher = function (dispatch) { return function (action) {
    var baseDispatcher = compose(dispatch, action);
    if (!isAsyncActionCreator(action)) {
        return baseDispatcher;
    }
    var asyncAction = action;
    var extensions = {
        request: compose(dispatch, asyncAction.request),
        success: compose(dispatch, asyncAction.success),
        failure: compose(dispatch, asyncAction.failure),
        cancel: compose(dispatch, asyncAction.cancel),
    };
    return Object.assign(baseDispatcher, extensions);
}; };
/**
 * bindActionCreators
 *
 * Monkeypatches dispatch to the actions making them self-dispachable
 *
 * @param actions
 */
export var bindActionCreators = function (actions) { return function (dispatch) { return ({
    actions: transformTree(toDispatcher(dispatch), actions),
}); }; };
export var applySelectors = function (spec) {
    return applySpec(spec);
};
/**
 * connectWithActions
 *
 * Wraps react-redux's "connect" helper, binding dispatch to the action-creators
 *
 * @param actions - object of action-creators
 * @param mapStateToProps -
 * It can either be a function that directly maps the app's State to a component's Props
 * or an object whose keys represent properties in the target component and values are functions
 * that take the application's State and optionally, the connected component's own Props.
 * Those functions then return a derived value that matches the component's contract.
 * Ideally should be used with redux selectors.
 *
 */
export var connectWithActions = function (actions, mapStateToProps) {
    var stateToProps = typeof mapStateToProps === "object"
        ? applySelectors(mapStateToProps)
        : mapStateToProps;
    return connect(stateToProps, bindActionCreators(actions));
};
//# sourceMappingURL=redux.js.map